@@ -31,24 +31,15 @@ class _OutputLogger(Logger):
         self._logs[process].append(message)
 
     def debug(self, msg, *args, **kwargs):
-        formatted = msg
-        if args:
-            formatted = msg % args
-        self._logs["debug"].append(formatted)
+        self._logs["debug"].append(msg)
         super().debug(msg, *args, **kwargs)
 
     def info(self, msg, *args, **kwargs):
-        formatted = msg
-        if args:
-            formatted = msg % args
-        self._logs["info"].append(formatted)
+        self._logs["info"].append(msg)
         super().info(msg, *args, **kwargs)
 
     def warning(self, msg, *args, **kwargs):
-        formatted = msg
-        if args:
-            formatted = msg % args
-        self._logs["warning"].append(formatted)
+        self._logs["warning"].append(msg)
         super().warning(msg, *args, **kwargs)
 
     def clear_log_history(self):
